@@ -19,7 +19,6 @@
 
 #include "transportmgr.h"
 
-#include <widgets/transportconfigdialog.h>
 #include <transportmanager.h>
 #include <widgets/transportmanagementwidget.h>
 #include <transportjob.h>
@@ -79,7 +78,7 @@ TransportMgr::TransportMgr()
 void TransportMgr::removeAllBtnClicked()
 {
     MailTransport::TransportManager *manager = MailTransport::TransportManager::self();
-    QList<Transport *> transports = manager->transports();
+    const QList<Transport *> transports = manager->transports();
     for (int i = 0; i < transports.count(); i++) {
         MailTransport::Transport *transport = transports.at(i);
         qDebug() << transport->host();
@@ -93,13 +92,13 @@ void TransportMgr::editBtnClicked()
     if (index < 0) {
         return;
     }
-    TransportManager::self()->configureTransport(TransportManager::self()->transportById(index), this);
+    const auto transport = TransportManager::self()->transportById(index);
+    TransportManager::self()->configureTransport(transport->identifier(), transport, this);
 }
 
 void TransportMgr::sendBtnClicked()
 {
-    TransportJob *job;
-    job = TransportManager::self()->createTransportJob(mComboBox->currentTransportId());
+    TransportJob *job = TransportManager::self()->createTransportJob(mComboBox->currentTransportId());
     if (!job) {
         qDebug() << "Invalid transport!";
         return;
